@@ -24,7 +24,7 @@
 #endif
 
 /* Global includes */
-#ifdef HAVE_LIBNOTIFY
+#if defined(HAVE_LIBNOTIFY4) || defined(HAVE_LIBNOTIFY7)
 #include <libnotify/notify.h>
 #endif
 /* #include <stdlib.h> */
@@ -71,10 +71,10 @@ fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale, t_senso
     t_chipfeature *chipfeature;
     gboolean *suppress;
     GtkTreeIter *iter;
-    #ifdef HAVE_LIBNOTIFY
+#if defined(HAVE_LIBNOTIFY4) || defined(HAVE_LIBNOTIFY7)
     NotifyNotification *nn;
     GError *error = NULL;
-    #endif
+#endif
     gchar *summary, *body, *icon;
     float minval, maxval;
 
@@ -101,15 +101,20 @@ fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale, t_senso
                     (chip, chipfeature->address, &sensorFeature, suppress);
             if ( res!=0 && !suppress) {
 
-                #ifdef HAVE_LIBNOTIFY
+#if defined(HAVE_LIBNOTIFY4) || defined(HAVE_LIBNOTIFY7)
                 if (!notify_is_initted())
                     notify_init(PACKAGE); /* NOTIFY_APPNAME */
-
-                nn = notify_notification_new(summary, body, icon, NULL);
+                    
+#ifdef HAVE_LIBNOTIFY4
+                nn = notify_notification_new (summary, body, icon, NULL);
+#endif
+#ifdef HAVE_LIBNOTIFY7
+                nn = notify_notification_new (summary, body, icon);
+#endif
                 notify_notification_show(nn, &error);
-                #else
+#else
                 DBG("%s\n%s", summary, body);
-                #endif
+#endif
 
                 /* FIXME: Better popup a window or DBG message or quit plugin. */
                 break;
@@ -140,7 +145,7 @@ fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale, t_senso
                                 //3, maxval,
                                  //-1);
         } /* end if sensors-valid */
-        /* g_free(iter); ??? */
+        /* gtk_tree_iter_free(iter); */
     }
 
     TRACE ("leaves fill_gtkTreeStore");
@@ -175,6 +180,7 @@ add_type_box (GtkWidget * vbox, t_sensors_dialog * sd)
         gtk_combo_box_get_active(GTK_COMBO_BOX(sd->myComboBox));
 
     chip = g_ptr_array_index (sd->sensors->chips, gtk_combo_box_active);
+		DBG("index: %d, chip: %p\n", gtk_combo_box_active, chip);
 
     /* if (sd->sensors->num_sensorchips > 0)
         sd->mySensorLabel = gtk_label_new
@@ -191,8 +197,7 @@ add_type_box (GtkWidget * vbox, t_sensors_dialog * sd)
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-    sd->mySensorLabel =
-            gtk_label_new (chip->description);
+    sd->mySensorLabel = gtk_label_new (chip->description);
 
     gtk_widget_show (sd->mySensorLabel);
     gtk_box_pack_start (GTK_BOX (hbox), sd->mySensorLabel, FALSE, FALSE, 0);
